@@ -7,7 +7,7 @@ use Types::Standard qw/Maybe/;
 use Types::Path::Tiny qw/Path/;
 use String::ShellQuote;
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 =head1 NAME
 
@@ -54,7 +54,7 @@ Doesn't work on win32.
 =cut
 
 has verbose     => (is => 'rw',   default => sub { 0 });
-has print_cmd   => (is => 'ro',   default => sub { 0 });
+has print_cmd   => (is => 'rw',   default => sub { 0 });
 has ssh_cmd     => (is => 'lazy', default => sub { '/usr/bin/ssh' });
 has ssh_options => (is => 'lazy', default => sub { [] });
 has noop        => (is => 'rw', default => sub { 0 });
